# Phase 2. Prepare the Transformation
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/erp-transformation-prepare#overview)
  * [Step 1. Enrich Data](https://help.sap.com/docs/leanix/ea/erp-transformation-prepare#step-1.-enrich-data)
  * [Add Initiatives](https://help.sap.com/docs/leanix/ea/erp-transformation-prepare#add-initiatives)
  * [Add Milestones](https://help.sap.com/docs/leanix/ea/erp-transformation-prepare#add-milestones)
  * [Structure Your Transformation Program](https://help.sap.com/docs/leanix/ea/erp-transformation-prepare#structure-your-transformation-program)
  * [Step 2. Evaluate Data](https://help.sap.com/docs/leanix/ea/erp-transformation-prepare#step-2.-evaluate-data)
  * [Step 3. Report and Communicate](https://help.sap.com/docs/leanix/ea/erp-transformation-prepare#step-3.-report-and-communicate)


Build high-level transformation scenarios and plan a detailed roadmap.
